==> haskell-persistent-postgresql-2.13.5.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.5.0
visibility:           public
id:                   persistent-postgresql-2.13.5.0-86hbeDSbOdI2FwyJme9AM7
key:                  persistent-postgresql-2.13.5.0-86hbeDSbOdI2FwyJme9AM7
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  742f6008882470102079b7ede662c39d
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.5.0-86hbeDSbOdI2FwyJme9AM7
depends:
    aeson-2.1.2.1-JT1gbb2shwLLy3Tf1UBGhr
    attoparsec-0.14.4-L7VTmm7vDKMCukUYiUxbnG base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    conduit-1.3.6.1-8DaA0acFUeIAhiI07RCEeo containers-0.6.7
    monad-logger-0.3.42-AdM675YyxGBG2C6xN48bvm mtl-2.2.2
    persistent-2.14.5.1-HuMhTR1L1qLGJUF6vRlaRP
    postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1
    postgresql-simple-0.6.5.1-LZOlXXvV82R5mhQsJFKSiw
    resource-pool-0.2.3.2-64bBKdGm40SEFqsKcLJiJL
    resourcet-1.2.6-ImDiK8j9yhy8AYzQhyOU1O
    string-conversions-0.4.0.1-At29VEfYfYXoXdSzJB7Sz text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vault-0.3.1.5-Drju4AATmwGI4RivP1rPtZ

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-postgresql-2.13.5.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.5.0
visibility:           public
id:                   persistent-postgresql-2.13.5.0-HXujoB7vaidGbInbTTd5kM
key:                  persistent-postgresql-2.13.5.0-HXujoB7vaidGbInbTTd5kM
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  7178e9699673f7285523d3f6c16a7e9a
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.5.0-HXujoB7vaidGbInbTTd5kM
depends:
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0
    attoparsec-0.14.4-CiUWnNTnUzcEcRmqqSBimu base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    conduit-1.3.6.1-GhV2KMoemFPB5FDryFR5X5 containers-0.6.7
    monad-logger-0.3.42-AQcgAh9wba2AXEOYEs9uhR mtl-2.2.2
    persistent-2.14.5.1-ACPhqaDIO2DzaMw7Q8faI
    postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1
    postgresql-simple-0.6.5.1-8HquMDomIq3AEVIA9tW6d1
    resource-pool-0.2.3.2-HU85X3eIW3oAXSBd1CIWxz
    resourcet-1.2.6-1qaZdHoBp5u2zlBnaE55JI
    string-conversions-0.4.0.1-At29VEfYfYXoXdSzJB7Sz text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vault-0.3.1.5-5e7UPRpTdU3Hv4JOD2zFGu

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
